@@ -248,7 +248,7 @@ public class LibGlade {
     private static native void initIDs();
 
     static {
-        System.loadLibrary("gladejava2.9");
+        System.loadLibrary("gladejni-2.9");
         initIDs();
     }
 }
